# Authors

The following people have contributed to the project (in alphabetical order):

- [Evan Bianco](https://github.com/EvanBianco), Agile Scientific, Canada
- [Jesper Dramsch](https://github.com/JesperDramsch), Edinburgh, UK
- [Matt Hall](https://github.com/kwinkunks), Agile Scientific, Canada / [ORCID: 0000-0002-4054-8295]( https://orcid.org/0000-0002-4054-8295))
- [Kent Inverarity](https://github.com/kinverarity1), South Australia
- [Rob Leckenby](https://github.com/Zabamund), Agile Scientific, Switzerland
- [Thomas Martin](https://github.com/ThomasMGeo), Colorado, USA
- [Steve Purves](https://github.com/stevejpurves), Curvenote, Spain
- [Patrick Reinhard](https://github.com/patrick-reinhard), Shell, The Netherlands
- [DC Slagel](https://github.com/dcslagel), Shell, The Netherlands
- [Miguel de la Varga](https://github.com/Leguark), Germany
- [Wenting Xiong](https://github.com/wenting-x), Shell, The Netherlands
